# ProPublica Recidivism/COMPAS

## Source:
<https://github.com/propublica/compas-analysis>

This dataset is used to assess the likelihood that a criminal defendant will re-offend. The dataset used consisted of

## Download instructions

Download the following file and place it as-is in the current folder

1. [compas-scores-two-years.csv](https://github.com/propublica/compas-analysis/blob/master/compas-scores-two-years.csv)


## Relevant Papers

* J. Angwin, J. Larson, S. Mattu, L. Kirchner, [“Machine bias: There’s software used across the country to predict future criminals. And it’s biased against blacks,”](https://www.propublica.org/article/machine-bias-risk-assessments-in-criminal-sentencing) ProPublica, 23 May 2016
